@@ -25,9 +25,9 @@ hb <- function(a, b, d, f, env=parent.frame())
           
                out    <- nextB(a, b, d, p, f, env)
                b      <- out[[1]]
-               accept <- out[[2]]
+               env$acceptanceRatePerc <- out[[2]]
                p      <- out[[3]]
-          
+               
                a <- nextA(b, d, env)
                
                # this constrains the means of the random parameters to be user-specified
@@ -49,12 +49,53 @@ hb <- function(a, b, d, f, env=parent.frame())
                if(env$gFULLCV==0) {
                     d <- nextDind(a, b, env)
                }
+               
+               #if((r%%100)==0)
+               #{
+               #     print(d)     
+               #}
+               
+               if(!is.null(env$fixedD))
+               {
+                    for(rp in 1:env$gNIV)
+                    {
+                         if(!is.na(env$fixedD[rp]))
+                         {
+                              d[rp,rp] <- env$fixedD[rp]     
+                         }
+                    }
+               } 
+               
+               
           }
 
           # drawing a new set of fixed coefficients
           if(env$gFIV > 0) {
+               
                out <- nextF(p,f,b,env)
                
+               if(sum(out[[1]]==f)!=env$gFIV)
+               {
+                    env$acceptanceRateF <- env$acceptanceRateF + 1
+               }
+               
+               # targeting an acceptance rate of 0.25
+               if((r%%100)==0)
+               {
+                    env$acceptanceRateFPerc <- env$acceptanceRateF/100
+                    
+                    if(env$acceptanceRateFPerc < env$targetAcceptanceFixed)
+                    {
+                         env$rhoF <- env$rhoF - env$rhoF/50 
+                    }
+                    if(env$acceptanceRateFPerc > env$targetAcceptanceFixed)
+                    {
+                         env$rhoF <- env$rhoF + env$rhoF/50
+                    }               
+                    
+                    env$acceptanceRateF <- 0
+               }     
+                    
                f  <- out[[1]]
                p  <- out[[2]]     
           }
@@ -84,7 +125,7 @@ hb <- function(a, b, d, f, env=parent.frame())
                     
                out    <- nextB(a, b, d, p, f, env)
                b      <- out[[1]]
-               accept <- out[[2]]
+               env$acceptanceRatePerc <- out[[2]]
                p      <- out[[3]]     
                
                a <- nextA(b, d, env)
@@ -109,6 +150,17 @@ hb <- function(a, b, d, f, env=parent.frame())
                     d <- nextDind(a, b, env)
                }
                
+               if(!is.null(env$fixedD))
+               {
+                    for(rp in 1:env$gNIV)
+                    {
+                         if(!is.na(env$fixedD[rp]))
+                         {
+                              d[rp,rp] <- env$fixedD[rp]    
+                         }
+                    }
+               }   
+               
                if(r%%env$gNSKIP == 0) {
                     C <- trans(b,env)
                     env$ma[ ,(r/env$gNSKIP)] <- a
@@ -133,6 +185,29 @@ hb <- function(a, b, d, f, env=parent.frame())
           if(env$gFIV > 0){
                # drawing a new set of fixed coefficients
                out <- nextF(p,f,b,env)
+               
+               if(sum(out[[1]]==f)!=env$gFIV)
+               {
+                    env$acceptanceRateF <- env$acceptanceRateF + 1
+               }
+               
+               # targeting an acceptance rate of 0.25
+               if((r%%100)==0)
+               {
+                    env$acceptanceRateFPerc <- env$acceptanceRateF/100
+                    
+                    if(env$acceptanceRateFPerc < env$targetAcceptanceFixed)
+                    {
+                         env$rhoF <- env$rhoF - env$rhoF/50 
+                    }
+                    if(env$acceptanceRateFPerc > env$targetAcceptanceFixed)
+                    {
+                         env$rhoF <- env$rhoF + env$rhoF/50
+                    }               
+                    
+                    env$acceptanceRateF <- 0
+               }                          
+
                f   <- out[[1]]
                p   <- out[[2]]
                
@@ -143,9 +218,7 @@ hb <- function(a, b, d, f, env=parent.frame())
           }              
           
           if(r%%env$gINFOSKIP == 0) {
-               
                writeLog(env$gNCREP + r,p,a,b,d,f,env)
-               
           }
      }
      
